var g_start_lon = 0.0;
var g_start_lat = 0.0;

var points_array = [];

var map = new OpenLayers.Map("myMap", {
    controls: []});

function generateMap(start_lon, start_lat, start_zoom) {
    g_start_lon = start_lon;
    g_start_lat = start_lat;

    map.addControl(new OpenLayers.Control.Navigation());

    layerCycleMap = new OpenLayers.Layer.OSM.CycleMap("CycleMap");
    map.addLayer(layerCycleMap);

    var newLayer = new OpenLayers.Layer.OSM("Local Tiles", "tiles/${z}/${x}/${y}.png", {numZoomLevels: 16, alpha: true, isBaseLayer: false});
    map.addLayer(newLayer);

    if (!map.getCenter()) {
        var lonLat = new OpenLayers.LonLat(start_lon, start_lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
        map.setCenter(lonLat, start_zoom);
    }

    var bounds = new OpenLayers.Bounds();
    bounds.extend(new OpenLayers.LonLat(20.4208, 41.5230).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()));
    bounds.extend(new OpenLayers.LonLat(21.3162, 42.2367).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()));
    bounds.toBBOX();

    map.setOptions({restrictedExtent: bounds});

    var lonLat = new OpenLayers.LonLat(start_lon, start_lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
    map.setCenter(lonLat, start_zoom);

    trackMe();

    //prevents user from zooming out
    window.setInterval("preventZoomOut()", 100);
}

function preventZoomOut() {
    var c_zoom = map.zoom;
    if (c_zoom < 13) {
        var a = map.getCenter();
        var lonLat = new OpenLayers.LonLat(a).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
        map.setCenter(lonLat, 13);
    }
}

function goOnStart() {
    var c_zoom = map.zoom;
    var lonLat = new OpenLayers.LonLat(g_start_lon, g_start_lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
    map.setCenter(lonLat, c_zoom);
}

function drawCoordinates(lineLayer) {
    var style = {
        strokeColor: '#0000ff',
        strokeOpacity: 0.5,
        strokeWidth: 5
    };

    var x = 0;

    while (x < total_coordinates - 2) {
        var points = new Array(
                new OpenLayers.Geometry.Point(parseFloat(coordinates_array[x + 1]), parseFloat(coordinates_array[x])).transform(new OpenLayers.Projection("EPSG:4326"),
                map.getProjectionObject()),
                new OpenLayers.Geometry.Point(parseFloat(coordinates_array[x + 3]), parseFloat(coordinates_array[x + 2])).transform(new OpenLayers.Projection("EPSG:4326"),
                map.getProjectionObject())
                );

        var line = new OpenLayers.Geometry.LineString(points);

        var lineFeature = new OpenLayers.Feature.Vector(line, null, style);
        lineLayer.addFeatures([lineFeature]);
        x = x + 2;
    }
}

function trackMe() {
    var style = {
        fillColor: '#000',
        fillOpacity: 0.1,
        strokeWidth: 0
    };

    var vector = new OpenLayers.Layer.Vector('vector');

    map.addLayers([vector]);

    var pulsate = function (feature) {
        var point = feature.geometry.getCentroid(),
                bounds = feature.geometry.getBounds(),
                radius = Math.abs((bounds.right - bounds.left) / 2),
                count = 0,
                grow = 'up';

        var resize = function () {
            if (count > 16) {
                clearInterval(window.resizeInterval);
            }
            var interval = radius * 0.03;
            var ratio = interval / radius;
            switch (count) {
                case 4:
                case 12:
                    grow = 'down';
                    break;
                case 8:
                    grow = 'up';
                    break;
            }
            if (grow !== 'up') {
                ratio = -Math.abs(ratio);
            }
            feature.geometry.resize(1 + ratio, point);
            vector.drawFeature(feature);
            count++;
        };
        window.resizeInterval = window.setInterval(resize, 50, point, radius);
    };

    var geolocate = new OpenLayers.Control.Geolocate({
        bind: false,
        geolocationOptions: {
            enableHighAccuracy: true,
            maximumAge: 0,
            timeout: 7000
        }
    });

    map.addControl(geolocate);

    var firstGeolocation = true;

    geolocate.events.register("locationupdated", geolocate, function (e) {
        vector.removeAllFeatures();
        var circle = new OpenLayers.Feature.Vector(
                OpenLayers.Geometry.Polygon.createRegularPolygon(
                        new OpenLayers.Geometry.Point(e.point.x, e.point.y),
                        e.position.coords.accuracy / 2,
                        40,
                        0
                        ),
                {},
                style
                );
        vector.addFeatures([
            new OpenLayers.Feature.Vector(
                    e.point,
                    {},
                    {
                        graphicName: 'cross',
                        strokeColor: '#f00',
                        strokeWidth: 2,
                        fillOpacity: 0,
                        pointRadius: 10
                    }
            ),
            circle
        ]);
        if (firstGeolocation) {
            map.zoomToExtent(vector.getDataExtent());
            pulsate(circle);
            firstGeolocation = false;
            this.bind = true;
        }
    });

    geolocate.events.register("locationfailed", this, function () {
        OpenLayers.Console.log('Location detection failed');
    });

    document.getElementById('track').onclick = function () {
        //notify user
        vector.removeAllFeatures();
        geolocate.deactivate();
        if (this.checked) {
            alert("Се обидуваме да ве лоцираме, ве молиме почекајте \nи бидете сигурни дека вашиот GPS е вклучен!");
            geolocate.watch = true;
            firstGeolocation = true;
            geolocate.activate();
        }
    };

    document.getElementById('track').checked = false;
}

function loadPointsInfo() {
    var oFrame = document.getElementById('PointsInfo');
    var strRawContents = oFrame.contentWindow.document.body.childNodes[0].innerHTML;
    while (strRawContents.indexOf("\r") >= 0)
        strRawContents = strRawContents.replace("\r", "");
    var arrLines = strRawContents.split("\n");
    for (var i = 0; i < arrLines.length; i++) {
        var curLine = arrLines[i];
        points_array.push(curLine);
    }
}

function addPoint(lon, lat, path, text) {
    var markers = new OpenLayers.Layer.Markers("Markers");
    map.addLayer(markers);

    var size = new OpenLayers.Size(30, 33);
    var offset = new OpenLayers.Pixel(-(size.w / 2), -size.h * 1.2);
    var icon = new OpenLayers.Icon(path, size, offset);
   
    markers.addMarker(new OpenLayers.Marker(new OpenLayers.LonLat(lon, lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()), icon));
    markers.addMarker(new OpenLayers.Marker(new OpenLayers.LonLat(lon, lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()), icon.clone()));

    var renderer = OpenLayers.Util.getParameters(window.location.href).renderer;
    renderer = (renderer) ? [renderer] : OpenLayers.Layer.Vector.prototype.renderers;

    var vectorLayer = new OpenLayers.Layer.Vector("Simple Geometry", {
        styleMap: new OpenLayers.StyleMap({'default': {
                strokeColor: "#00FF00",
                strokeOpacity: 1,
                strokeWidth: 3,
                fillColor: "#FF5500",
                fillOpacity: 0.5,
                pointRadius: 0,
                pointerEvents: "visiblePainted",
                label: "${name}",
                fontColor: "${favColor}",
                fontSize: "14px",
                fontFamily: "Arial, monospace",
                fontWeight: "bold",
                labelAlign: "${align}",
                labelXOffset: "${xOffset}",
                labelYOffset: "${yOffset}",
                labelOutlineColor: "white",
                labelOutlineWidth: 2
            }}),
        renderers: renderer
    });

    var lonLat = new OpenLayers.LonLat(lon, lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
    var point = new OpenLayers.Geometry.Point(lonLat.lon, lonLat.lat);
    
    var pointFeature = new OpenLayers.Feature.Vector(point);
    pointFeature.attributes = {
        name: text,
        favColor: '#5d5b5b',
        align: "cm"
    };

    map.addLayer(vectorLayer);
    vectorLayer.addFeatures([pointFeature]);

}

function drawPoints(){
    loadPointsInfo();
    for(i = 0; i < points_array.length; i = i + 4){
        var kind = points_array[i+3];
        if(kind === "voda"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/drinkingwater.png', "water");
        }
        if(kind === "ezero"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/lake.png', points_array[i+2]);
        }
        if(kind === "vodopad"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/waterfall-2.png', points_array[i+2]);
        }
        if(kind === "vrv"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/mountains.png', points_array[i+2]);
        }
        if(kind === "dom"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/home-2.png', points_array[i+2]);
        }
        if(kind === "platozaparking"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/parking.png', "Off-road parking");
        }
        if(kind === "shuma"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/forest2.png', points_array[i+2]);
        }
        if(kind === "kamp"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/camp.png', points_array[i+2]);
        }
        if(kind === "bachilo"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/bacilo.png', points_array[i+2]);
        }
        if(kind === "tvrdjava"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/castle-2.png', "fortress");
        }if(kind === "crkva"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/church-2.png', "Monastery St. Naum Cudotvorec");
        }
        if(kind === "ski-centar"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/skiing.png', "Ski center Popova Sapka");
        }
        if(kind === "raskrsnica"){
            addPoint(points_array[i+1], points_array[i], '../img/symbols/crossroad.png', "junction");
        }
        
    }
}